@@ -31,7 +31,7 @@ def basic_matching_example(query: str = "Apple", limit: int = 3, min_score: floa
     
     for i, match in enumerate(matches, 1):
         print(f"{i}. {match['original_name']}")
-        print(f"   Score: {match['canonical_name']}")
+        print(f"   Score: {match['score']}")
         print(f"   LEI: {match['lei']}")
         print(f"   Country: {match['country']}")
         print()
